@@ -3,12 +3,15 @@ import time
 import sys
 import httpx
 import requests
+import string
+import os
+import mechanize
 import json as _json
 from httpx import AsyncClient
 from datetime import datetime
-import mechanize
 from bs4 import BeautifulSoup
 from collections.abc import Iterable
+from webeye.rot import encoding
 from typing import Union
 from concurrent.futures import ThreadPoolExecutor
 
@@ -32,6 +35,11 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 '''
 
+# Helper Functions
+def listtodict(lst):
+    it = iter(lst)
+    response = dict(zip(it, it))
+    return response
 
 def extract_pagelinks(host: str, cli=False) -> Union[list, None]:
     '''Extract All Pagelinks From Website'''
@@ -107,9 +115,10 @@ def scan(target: str, port: Union[int, Iterable], start: int=0, dev_mode: bool=F
     except KeyboardInterrupt:
         return sys.exit('Process Stopped Exiting: 1')
 
-def subenum(host: str, cli=False, no_ip=True) -> Union[list, None]:
+def subenum(host: str, cli=False, no_ip=True) -> Union[list, dict, None]:
     """Enumerate a list of subdomains for given host Asynchronously"""
     try:
+        GLOBAL_LIST = []
         api = requests.get(f"https://api.hackertarget.com/hostsearch/?q={host}")
         lines = api.text.split("\n")
         if '' in lines:
@@ -127,7 +136,15 @@ def subenum(host: str, cli=False, no_ip=True) -> Union[list, None]:
                 else:
                     print(f"{v[0].ljust(60,' ')} | {v[1].rjust(40,' ')}  << ({i})")
         else:
-            return list(line.split(',')[0] for line in lines)
+            if no_ip:
+                return list(line.split(',')[0] for line in lines)
+            else:
+                for line in lines:
+                    x = line.split(',')
+                    for j in x:
+                        GLOBAL_LIST.append(j)
+                return listtodict(GLOBAL_LIST)
+
     except requests.ConnectionError:
         return 'Connection Lost: Retry Again'
     except requests.ConnectTimeout:
@@ -163,6 +180,7 @@ def grab(host: str, schema='http://', cli=False) -> Union[dict, None]:
         return sys.exit('Stopped, Exiting: 1')
 
 def whois(target: str) -> str:
+    """ Whois Lookup for a Given Host """
     browser = mechanize.Browser()
     url = 'https://www.ipvoid.com/whois/'
     browser.open(url)
@@ -175,6 +193,7 @@ def whois(target: str) -> str:
     return result
 
 def geoip(host: str, cli=False) -> Union[dict, None]:
+    '''Geolocation Enumeration for a given host'''
     realip = socket.gethostbyname(host)
     api= requests.get(f'http://ip-api.com/json/{realip}?fields=66846715').json()
     if not cli:
@@ -185,6 +204,37 @@ def geoip(host: str, cli=False) -> Union[dict, None]:
             a+=1
             print(f'{a}). {x}: {y}')
 
+def encode(text: str, rot: int=0):
+    '''Encode text from ROT_1 - ROT_25
+    eg:- webeye.encode('hello', type='rot-13')
+    '''
+    if rot > 25:
+        return f"Unable to rotate text in rot-{rot}"
+    elif rot < 0:
+        return 'rotation cannot be in negetive value'
+    if rot == 0:
+        return text.upper()
+    else:
+        letters = string.ascii_uppercase + string.ascii_lowercase 
+        _rot = encoding[f'rot-{str(rot)}']
+        rot = text.maketrans(letters, _rot)
+        return text.translate(rot)
+
+def decode(text: str, rot: int) -> str:
+    '''Decode text from ROT_1 - ROT_25
+    eg:- webeye.encode('hello', type='rot-13')
+    '''
+    if rot > 25:
+        return f"Unable to rotate text in rot-{rot}"
+    elif rot < 0:
+        return 'rotation cannot be in negetive value'
+    if rot == 0:
+        return text.upper()
+    else:
+        letters = string.ascii_uppercase + string.ascii_lowercase 
+        _rot = encoding[f'rot-{str(rot)}']
+        rot = text.maketrans(_rot, letters)
+        return text.translate(rot)
 
 def is_cloudflare(host: str, schema='http://', cli=False) -> Union[bool, None]:
     '''Check For Cloudflare in a given host'''
@@ -336,10 +386,11 @@ class AsyncHelper:
         except KeyboardInterrupt:
             return sys.exit('Process Stopped Exiting: 1')
 
-    async def find_subdomains(self,host: str, cli=False, no_ip=True) -> Union[list, None]:
+    async def find_subdomains(self,host: str, cli=False, no_ip=True) -> Union[list, dict, None]:
         """Enumerate a list of subdomains for given host Asynchronously"""
         try:
             async with AsyncClient() as session:
+                RESPONSE = []
                 api = await session.get(f"https://api.hackertarget.com/hostsearch/?q={host}")
                 lines = api.text.split("\n")
                 if cli:
@@ -355,7 +406,14 @@ class AsyncHelper:
                         else:
                             print(f"{v[0].ljust(60,' ')} | {v[1].rjust(40,' ')}  << ({i})")
                 else:
-                    return list(line.split(',')[0] for line in lines)
+                    if no_ip:
+                        return list(line.split(',')[0] for line in lines)
+                    else:
+                        for line in lines:
+                            x = line.split(',')
+                            for j in x:
+                                RESPONSE.append(j)
+                        return listtodict(RESPONSE)
         except httpx.ConnectError:
             return 'Connection Lost: Retry Again'
         except httpx.ConnectTimeout:
@@ -402,6 +460,7 @@ class AsyncHelper:
             return 'Stopped, Exiting: 1'
 
     async def whois(target: str) -> str:
+        '''Whois Lookup of a Given Host'''
         try:
             browser = mechanize.Browser()
             url = 'https://www.ipvoid.com/whois/'
@@ -504,3 +563,7 @@ class AsyncHelper:
             return sys.exit('Stopped, Exiting: 1')
 
 
+
+# helper = AsyncHelper()
+# import asyncio
+# print(asyncio.run(helper.find_subdomains('zaeemtechnical.ml')))
